@@ -35,12 +35,7 @@ def json_fn(fn: str, input_j: dict, conn, attList,
         print('</code>')
     return output
 
-
-def print_json_by_attributes(j, attList, print_long_att: bool = False):
-    if not print_long_att:
-        print(json.dumps(j, indent=4, sort_keys=True))
-        return
-
+def convert_json_by_attributes(j, attList) -> str:
     abb_att = {}
 
     for a in attList:
@@ -51,7 +46,15 @@ def print_json_by_attributes(j, attList, print_long_att: bool = False):
     res = json.dumps(j, indent=4, sort_keys=True)
     for att in abb_att.keys():
         res = res.replace(att, abb_att[att])
-    print(res)
+
+    return res
+
+def print_json_by_attributes(j, attList, print_long_att: bool = False):
+    if not print_long_att:
+        print(json.dumps(j, indent=4, sort_keys=True))
+        return
+
+    print(convert_json_by_attributes(j, attList))
 
 
 def json_fn_db(
